@@ -24,9 +24,11 @@ class ExampleWidget(DOMWidget):
     _view_module_version = Unicode(module_version).tag(sync=True)
 
     value = Unicode('Hello World!').tag(sync=True)
+    # custom_cat = Unicode('{"col":{}, "row":{}}')
+    custom_cat = Unicode('{"col":"", "row":""}').tag(sync=True)
 
     mat_string = Unicode('ini_mat_string').tag(sync=True)
 
-    print('>> clustergrammer2 backend version 0.5.22')
+    print('>> clustergrammer2 backend version 0.6.0')
 
     network = Unicode('').tag(sync=True)
\ No newline at end of file
