@@ -14,7 +14,7 @@ import cgm_fun from 'clustergrammer-gl';
 import * as d3 from 'd3';
 
 console.log('*********************************************')
-console.log('** clustergrammer2 frontend version 0.5.22 **')
+console.log('** clustergrammer2 frontend version 0.6.0 **')
 console.log('*********************************************')
 
 export
@@ -28,6 +28,7 @@ class ExampleModel extends DOMWidgetModel {
       _view_module: ExampleModel.view_module,
       _view_module_version: ExampleModel.view_module_version,
       value : 'javascript set value!!!',
+      custom_cat: '{"col":"JS", "row":"JS"}',
       network: ''
     };
   }
@@ -57,18 +58,21 @@ function make_viz(args, cgm_model){
 
 var my_widget_callback = function(external_model){
 
-  // console.log('my_widget_callback')
+  console.log('my_widget_callback!!!!!!!!!!!!!!!!!!!1')
 
   var cgm = external_model.cgm;
   var params = cgm.params;
   var inst_value;
 
+  console.log(params.tooltip.tooltip_type)
 
   if (params.tooltip.tooltip_type === 'row-label'){
 
     // update row/column
     ////////////////////////
-    inst_value = params.tooltip.tooltip_type + ' -> ' + String(params.int.mouseover.row.name)
+    inst_value = params.tooltip.tooltip_type + ' -> ' +
+                 String(params.int.mouseover.row.name)
+
     external_model.model.set('value', inst_value);
     external_model.touch();
 
@@ -77,7 +81,9 @@ var my_widget_callback = function(external_model){
     // update second category
     ////////////////////////
     // params.int.mouseover[inst_axis].cats[mouseover_cat_index]
-    inst_value = params.tooltip.tooltip_type + ' -> ' + String(params.int.mouseover['col'].cats[0])
+    inst_value = params.tooltip.tooltip_type + ' -> ' +
+                 String(params.int.mouseover['col'].cats[0])
+
     external_model.model.set('value', inst_value);
     external_model.touch();
 
@@ -86,29 +92,20 @@ var my_widget_callback = function(external_model){
     // update first category
     ////////////////////////
     // params.int.mouseover[inst_axis].cats[mouseover_cat_index]
-    inst_value = params.tooltip.tooltip_type + ' -> ' + String(params.int.mouseover['col'].cats[1])
+    inst_value = params.tooltip.tooltip_type + ' -> ' +
+                 String(params.int.mouseover['col'].cats[1])
+
     external_model.model.set('value', inst_value);
     external_model.touch();
 
   } else if (params.tooltip.tooltip_type === 'col-dendro') {
 
-
       var selected_clust_names = params.dendro.selected_clust_names;
       var tmp_index;
       var real_index;
       var all_labels = new Array();
       var index_list = new Array();
 
-      // console.log(selected_clust_names)
-      // console.log(tmp_index)
-      // console.log(real_index)
-      // console.log(index_list)
-
-      // console.log('---------------------------------------------')
-      // console.log('checking all columns')
-      // console.log(params.labels.ordered_labels.cols)
-      // console.log('---------------------------------------------')
-
       // Parse titles out of labels (if necessary)
       var ini_all_labels = params.labels.ordered_labels.cols;
       var all_labels = new Array();
@@ -120,12 +117,6 @@ var my_widget_callback = function(external_model){
         all_labels.push(inst_label);
       }
 
-      // console.log('---------------------------------------------')
-      // console.log('checking all_labels - after parsing')
-      // console.log(all_labels)
-      // console.log('---------------------------------------------')
-
-
       // look up indexes in original dataframe
       for (let inst_name of selected_clust_names) {
 
@@ -134,17 +125,12 @@ var my_widget_callback = function(external_model){
         // get index of label
         tmp_index = all_labels.indexOf(inst_name)
 
-        // console.log(tmp_index)
         // look up index in original dataframe
         real_index = cgm.params.labels.ordered_labels.col_indices[tmp_index]
         index_list.push(real_index);
 
       }
 
-      // console.log('=============================================!!')
-      // console.log('checking index_list ')
-      // console.log(index_list)
-      // console.log('=============================================!!')
 
       var index_list_string = String(index_list)
 
@@ -152,20 +138,72 @@ var my_widget_callback = function(external_model){
       external_model.model.set('value', inst_value);
       external_model.touch();
 
-  } else {
-
-    console.log('OTHER')
-
-    inst_value = params.tooltip.tooltip_type; // 'other'
-
-    // update other
-    ////////////////////////
-    // external_model.model.set('value', String(null));
-    external_model.model.set('value', inst_value);
-    external_model.touch();
-
   }
+  // else {
 
+  //   console.log('OTHER')
+
+  //   inst_value = params.tooltip.tooltip_type; // 'other'
+
+  //   // update other
+  //   ////////////////////////
+  //   // external_model.model.set('value', String(null));
+  //   external_model.model.set('value', inst_value);
+  //   external_model.touch();
+
+  // }
+
+  // let ini_manual_cat_dict = {}
+  // if (params.cat_data.manual_cat_dict === '{"col":"", "row":""}'){
+  //   ini_manual_cat_dict = true
+  // } else {
+  //   ini_manual_cat_dict = false
+  // }
+
+
+  if (params.int.manual_update_cats){
+
+    let export_dict = {}
+
+      // transfer manual categories
+    if ('col' in params.cat_data.manual_cat_dict){
+      export_dict['col'] = params.cat_data.manual_cat_dict.col
+      export_dict['col_cat_colors'] = params.cat_colors.col['cat-0']
+    }
+
+    if ('row' in params.cat_data.manual_cat_dict){
+      export_dict['row'] = params.cat_data.manual_cat_dict.row
+      export_dict['row_cat_colors'] = params.cat_colors.row['cat-0']
+    }
+
+
+    // Object.keys(cgm.params.cat_colors.col['cat-0'])
+
+    // let axes = ['row', 'col']
+    // let cat_colors = {}
+    // let ini_cat_colors = {}
+    // let ini_cats
+
+
+    // if (axis in params.cat_colors){
+    //   ini_cat_colors[axis] = params.cat_colors[axis]['cat-0']
+    // }
+
+    // ini_cats = Object.keys(ini_cat_colors)
+
+    // ini_cats.forEach(x => {
+    //   cat_colors[x.split(': ')[1]] = ini_cat_colors[x]
+    // })
+
+    // // cleaned
+    // console.log('cleaned cat colors')
+    // console.log(cat_colors)
+
+    console.log('>>>>>>>>>>>>>>> manual_update_cats!!!!!!')
+    let json_string = JSON.stringify(export_dict)
+    external_model.model.set('custom_cat', json_string);
+    external_model.touch();
+  }
 }
 
 export
@@ -177,7 +215,7 @@ class ExampleView extends DOMWidgetView {
       .attr('id', this.cid)
       .style('width', '900px')
       .style('height', '1035px')
-      .style('border', '2px solid #eee');
+      // .style('border', '2px solid #eee')
 
     // define arguments object
     var args = {
@@ -193,7 +231,6 @@ class ExampleView extends DOMWidgetView {
 
     this.model.on('change:value', this.value_changed, this);
 
-
   }
 
   value_changed() {
